==> enjoyn-0.1.1.tar.gz: enjoyn-0.1.1/README.md <==
<p align="center">
   <a href="https://github.com/ahuang11/enjoyn" alt="Enjoyn Logo">
    <img src="https://raw.githubusercontent.com/ahuang11/enjoyn/main/docs/enjoyn_white.svg" /></a>
   <br>
   <a href="https://pypi.python.org/pypi/enjoyn/" alt="PyPI version">
     <img alt="PyPI" src="https://img.shields.io/pypi/v/enjoyn?color=CA2A7A&labelColor=090422"></a>
   <a href="https://github.com/ahuang11/enjoyn/" alt="Stars">
     <img src="https://img.shields.io/github/stars/ahuang11/enjoyn?color=CA2A7A&labelColor=090422" /></a>
   <a href="https://pepy.tech/badge/enjoyn/" alt="Downloads">
     <img src="https://img.shields.io/pypi/dm/enjoyn?color=CA2A7A&labelColor=090422" /></a>
   <a href="https://github.com/ahuang11/enjoyn/pulse" alt="Activity">
     <img src="https://img.shields.io/github/commit-activity/m/ahuang11/enjoyn?color=CA2A7A&labelColor=090422" /></a>
   <a href="https://github.com/ahuang11/enjoyn/graphs/contributors" alt="Contributors">
     <img src="https://img.shields.io/github/contributors/ahuang11/enjoyn?color=CA2A7A&labelColor=090422" /></a>
   <a href="https://github.com/ahuang11/enjoyn/tree/main/tests" alt="Coverage">
     <img src="https://raw.githubusercontent.com/ahuang11/enjoyn/main/docs/coverage.svg" /></a>
</p>

## Welcome!

Generate and animate images in parallel, enjoyably.

## Getting Started

### Installation

Install `enjoyn` with `pip`:

```bash
pip install enjoyn
```

Requires an installation of Python 3.7+.

## Resources

The full documentation can be found [here](https://enjoyn.readthedocs.io/en/latest/index.html).

If you encounter any bugs while using `enjoyn`, feel free to [open an issue](https://github.com/ahuang11/enjoyn/issues).

If you have any questions or issues while using `enjoyn`, ask away in [discussions](https://github.com/ahuang11/enjoyn/discussions/)!

Don't forget to star the project if you like the project!

==> enjoyn-0.1.3.tar.gz: enjoyn-0.1.3/README.md <==
<p align="center">
   <a href="https://github.com/ahuang11/enjoyn" alt="Enjoyn Logo">
    <img src="https://raw.githubusercontent.com/ahuang11/enjoyn/main/docs/assets/enjoyn_white.svg" /></a>
   <br>
   <a href="https://pypi.python.org/pypi/enjoyn/" alt="PyPI version">
     <img alt="PyPI" src="https://img.shields.io/pypi/v/enjoyn?color=CA2A7A&labelColor=090422"></a>
   <a href="https://github.com/ahuang11/enjoyn/" alt="Stars">
     <img src="https://img.shields.io/github/stars/ahuang11/enjoyn?color=CA2A7A&labelColor=090422" /></a>
   <a href="https://pepy.tech/badge/enjoyn/" alt="Downloads">
     <img src="https://img.shields.io/pypi/dm/enjoyn?color=CA2A7A&labelColor=090422" /></a>
   <a href="https://github.com/ahuang11/enjoyn/pulse" alt="Activity">
     <img src="https://img.shields.io/github/commit-activity/m/ahuang11/enjoyn?color=CA2A7A&labelColor=090422" /></a>
   <a href="https://github.com/ahuang11/enjoyn/graphs/contributors" alt="Contributors">
     <img src="https://img.shields.io/github/contributors/ahuang11/enjoyn?color=CA2A7A&labelColor=090422" /></a>
   <a href="https://github.com/ahuang11/enjoyn/tree/main/tests" alt="Coverage">
     <img src="https://raw.githubusercontent.com/ahuang11/enjoyn/main/docs/assets/coverage.svg" /></a>
</p>

## Welcome!

Generate and animate images in parallel, enjoyably.

## Getting Started

### Installation

Install `enjoyn` with `pip`:

```bash
pip install enjoyn
```

Requires an installation of Python 3.7+.

## Resources

The full documentation can be found [here](https://enjoyn.readthedocs.io/en/latest/index.html).

If you encounter any bugs while using `enjoyn`, feel free to [open an issue](https://github.com/ahuang11/enjoyn/issues).

If you have any questions or issues while using `enjoyn`, ask away in [discussions](https://github.com/ahuang11/enjoyn/discussions/)!

Don't forget to star the project if you like the project!
